@@ -33,7 +33,7 @@ class K3SController:
             error_info = info['detail']['error_info']
             raise error_factory.make(return_code)(error_info)
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def check_connection(self, timeout=30):
         response=requests.get(f'{self.url}', headers=self.header, timeout=timeout)
         info = json.loads(response.text)
@@ -43,7 +43,7 @@ class K3SController:
         else:
             return False
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def create_node(self, condition: ConditionDO, node_user_setting: NodeUserSettingDO, timeout=1200):
         data = {
             "condition": condition.to_json(),
@@ -55,7 +55,7 @@ class K3SController:
         self._check_error(response.status_code, info)
         return NodeInfoDO(**info)
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def delete_nodes(self, node_infos: List[NodeInfoDO], timeout=60):
         data = [info.to_json() for info in node_infos]
         data = json.dumps(data)
@@ -64,7 +64,7 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_existing_nodes(self, cluster_name: str, timeout=300):
         response=requests.get(f'{self.url}/nodes/cluster_name/{cluster_name}', 
             headers=self.header, timeout=timeout)
@@ -72,7 +72,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [NodeInfoDO(**info) for info in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_existing_nodes_by_name(self, node_name:str, timeout=300):
         response=requests.get(f'{self.url}/nodes/node_name/{node_name}', 
             headers=self.header, timeout=timeout)
@@ -80,7 +80,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [NodeInfoDO(**info) for info in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_node_metas(self, cluster_name: str, timeout=30):
         response=requests.get(f'{self.url}/node_metas/cluster_name/{cluster_name}', 
             headers=self.header, timeout=timeout)
@@ -88,7 +88,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [NodeMetaDO(**meta) for meta in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def add_node_label(self, node_infos: List[NodeInfoDO], key: str, value: str, timeout=30):
         data = [info.to_json() for info in node_infos]
         data = json.dumps(data)
@@ -98,7 +98,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [CommandResultDO(**r) for r in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_namespaces(self, cluster_name: str, timeout=30):
         response=requests.get(f'{self.url}/namespaces/cluster_name/{cluster_name}', 
             headers=self.header, timeout=timeout)
@@ -106,7 +106,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [NamespaceDO(**namespace) for namespace in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def create_namespace(self, cluster_name: str, namespace_name: str, timeout=30):
         response=requests.post(
             f'{self.url}/namespace/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
@@ -115,12 +115,12 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def create_secrets(
         self, 
         cluster_name: str, 
         secret_user_settings: List[SecretUserSettingDO],
-        timeout=30
+        timeout=300
     ):
         data = [setting.to_json() for setting in secret_user_settings]
         data = json.dumps(data)
@@ -131,7 +131,7 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_secrets(self, cluster_name: str, namespace_name: str, timeout=30):
         response=requests.get(
             f'{self.url}/secrets/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
@@ -140,12 +140,12 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [SecretDO(**s) for s in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def create_config_maps(
         self, 
         cluster_name: str, 
         config_map_user_settings: List[ConfigMapUserSettingDO],
-        timeout=30
+        timeout=300
     ):
         data = [setting.to_json() for setting in config_map_user_settings]
         data = json.dumps(data)
@@ -156,7 +156,7 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_config_maps(self, cluster_name:str, namespace_name:str, timeout=30):
         response=requests.get(
             f'{self.url}/config_maps/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
@@ -165,7 +165,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [ConfigMapDO(**s) for s in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def create_resource_from_oss(self, cluster_name:str, target_paths:List[str], timeout=60):
         resource_oss_setting = ResourceOSSSettingDO(
             cluster_name=cluster_name, target_paths=target_paths)
@@ -177,7 +177,7 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def delete_resource_from_oss(self, cluster_name: str, target_paths: List[str], timeout=60):
         resource_oss_setting = ResourceOSSSettingDO(
             cluster_name=cluster_name, target_paths=target_paths)
@@ -189,7 +189,7 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_deployments(self, cluster_name:str, namespace_name:str, timeout=30):
         response=requests.get(
             f'{self.url}/deployments/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
@@ -198,7 +198,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [DeploymentDO(**s) for s in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_ingresses(self, cluster_name:str, namespace_name:str, timeout=30):
         response=requests.get(
             f'{self.url}/ingresses/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
@@ -207,7 +207,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [IngressDO(**s) for s in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_pods(self, cluster_name:str, namespace_name:str, timeout=30):
         response=requests.get(
             f'{self.url}/pods/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
@@ -216,7 +216,7 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [PodDO(**s) for s in infos]
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def upload_to_oss_from_pod(self, pod_oss_operation_info: PodOSSOperationInfoDO, timeout=1200):
         data = json.dumps(pod_oss_operation_info.to_json())
         response=requests.post(
@@ -226,7 +226,7 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
-    @exception_class_dec()
+    @exception_class_dec(max_try=1)
     def get_services(self, cluster_name:str, namespace_name:str, timeout=30):
         response=requests.get(
             f'{self.url}/services/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
