@@ -1,78 +1,108 @@
 from typing import List
 from ddd_objects.infrastructure.converter import Converter
 from ..domain.entity import (
-    NodeInfo,
-    CommandResult,
-    Secret,
-    ResourceOSSSetting,
     Namespace,
-    PodOSSOperationInfo,
-    NodeUserSetting,
     Deployment,
-    NodeMeta,
-    ConfigMapUserSetting,
-    SecretUserSetting,
+    InstanceTypeUserSetting,
+    PodOSSOperationInfo,
+    InstanceInfo,
+    CommandSetting,
     Ingress,
+    Secret,
     Condition,
     ConfigMap,
-    Pod
+    OSSOperationInfo,
+    NodeInfo,
+    Service,
+    DNSRecord,
+    CommandResult,
+    InstanceUserSetting,
+    ConfigMapUserSetting,
+    InstanceTypeWithStatus,
+    Pod,
+    ResourceOSSSetting,
+    NodeUserSetting,
+    SecretUserSetting,
+    NodeMeta
 )
 from ..domain.value_obj import (
-    InstanceName,
-    DateTime,
-    Info,
-    ImageID,
-    InternetPayType,
-    SecurityGroupID,
+    Username,
+    NodeLabel,
     Output,
-    Value,
-    Hostname,
+    InstanceTypeStatus,
+    ID,
+    RegionID,
+    Endpoint,
+    Usage,
+    RecordID,
+    Command,
+    BandWidth,
     TimeInterval,
-    KeyType,
+    Type,
+    SecurityGroupID,
+    InstanceName,
     Number,
     Status,
-    NodeName,
-    Bool,
-    Price,
-    Key,
-    InstanceTypeStatus,
-    InstanceType,
-    Version,
-    IP,
-    PayType,
-    NodeType,
-    Type,
-    InstanceTypeStatusCategory,
     Path,
     Time,
-    BandWidth,
-    Name,
+    DNSType,
+    Key,
+    Value,
+    InstanceType,
+    NodeType,
+    Weight,
+    DomainName,
+    Port,
     ZoneID,
+    DNSLine,
+    Hostname,
     GPUType,
-    Token,
-    InstanceID,
-    Usage,
-    RegionID,
-    NodeLabel,
+    NodeName,
+    ImageID,
+    InstanceTypeStatusCategory,
+    Name,
+    ServiceType,
+    KeyType,
+    NodeStatus,
+    InternetPayType,
+    Version,
+    Bool,
+    Password,
     Size,
-    NodeStatus
+    IP,
+    Info,
+    InstanceID,
+    Price,
+    Subdomain,
+    Data,
+    Token,
+    PayType,
+    DateTime
 )
 from .do import (
-    SecretUserSettingDO,
-    NamespaceDO,
-    ResourceOSSSettingDO,
     NodeMetaDO,
-    ConditionDO,
-    ConfigMapDO,
-    ConfigMapUserSettingDO,
-    NodeInfoDO,
-    CommandResultDO,
-    NodeUserSettingDO,
-    DeploymentDO,
-    PodDO,
     SecretDO,
+    ConditionDO,
+    ConfigMapUserSettingDO,
+    NodeUserSettingDO,
+    NamespaceDO,
+    DNSRecordDO,
+    PodDO,
+    NodeInfoDO,
+    InstanceUserSettingDO,
+    ResourceOSSSettingDO,
+    CommandResultDO,
     PodOSSOperationInfoDO,
+    CommandSettingDO,
+    SecretUserSettingDO,
+    InstanceInfoDO,
+    ConfigMapDO,
+    InstanceTypeWithStatusDO,
     IngressDO,
+    DeploymentDO,
+    InstanceTypeUserSettingDO,
+    ServiceDO,
+    OSSOperationInfoDO
 )
 
 class ConditionConverter(Converter):
@@ -99,7 +129,6 @@ class ConditionConverter(Converter):
             max_gpu_memory_size = None if x.max_gpu_memory_size is None else x.max_gpu_memory_size.get_value()
         )
 
-
 class CommandResultConverter(Converter):
     def to_entity(self, do: CommandResultDO):
         return CommandResult(
@@ -118,7 +147,6 @@ class CommandResultConverter(Converter):
             succeed = None if x.succeed is None else x.succeed.get_value()
         )
 
-
 class NodeUserSettingConverter(Converter):
     def to_entity(self, do: NodeUserSettingDO):
         return NodeUserSetting(
@@ -259,19 +287,25 @@ class PodConverter(Converter):
     def to_entity(self, do: PodDO):
         return Pod(
             name = Name(do.name),
+            node_name = NodeName(do.node_name),
             status = Status(do.status),
             age = TimeInterval(do.age),
+            pod_ip = IP(do.pod_ip),
             namespace = Name(do.namespace),
             restarts = Number(do.restarts),
+            readiness_info = Info(do.readiness_info),
             _life_time = Number(do._life_time)
         )
     def to_do(self, x: Pod):
         return PodDO(
             name = None if x.name is None else x.name.get_value(),
+            node_name = None if x.node_name is None else x.node_name.get_value(),
             status = None if x.status is None else x.status.get_value(),
             age = None if x.age is None else x.age.get_value(),
+            pod_ip = None if x.pod_ip is None else x.pod_ip.get_value(),
             namespace = None if x.namespace is None else x.namespace.get_value(),
             restarts = None if x.restarts is None else x.restarts.get_value(),
+            readiness_info = None if x.readiness_info is None else x.readiness_info.get_value(),
             _life_time = None if x._life_time is None else x._life_time.get_value()
         )
 
@@ -443,4 +477,222 @@ class IngressConverter(Converter):
             age = None if x.age is None else x.age.get_value(),
             namespace = None if x.namespace is None else x.namespace.get_value(),
             _life_time = None if x._life_time is None else x._life_time.get_value()
+        )
+
+class InstanceInfoConverter(Converter):
+    def to_entity(self, do: InstanceInfoDO):
+        return InstanceInfo(
+            id = ID(do.id),
+            status = Status(do.status),
+            security_group_id = [SecurityGroupID(m) for m in do.security_group_id],
+            instance_type = InstanceType(do.instance_type),
+            name = Name(do.name),
+            hostname = Hostname(do.hostname),
+            price = Price(do.price),
+            image_id = ImageID(do.image_id),
+            region_id = RegionID(do.region_id),
+            zone_id = ZoneID(do.zone_id),
+            internet_pay_type = InternetPayType(do.internet_pay_type),
+            pay_type = PayType(do.pay_type),
+            create_time = DateTime(do.create_time),
+            os_name = Name(do.os_name),
+            public_ip = [IP(m) for m in do.public_ip],
+            private_ip = IP(do.private_ip),
+            bandwidth_in = BandWidth(do.bandwidth_in),
+            bandwidth_out = BandWidth(do.bandwidth_out),
+            expired_time = DateTime(do.expired_time),
+            auto_release_time = DateTime(do.auto_release_time),
+            key_name = Name(do.key_name),
+            _life_time = Number(do._life_time)
+        )
+    def to_do(self, x: InstanceInfo):
+        return InstanceInfoDO(
+            id = None if x.id is None else x.id.get_value(),
+            status = None if x.status is None else x.status.get_value(),
+            security_group_id = None if x.security_group_id is None else [m.get_value() for m in x.security_group_id],
+            instance_type = None if x.instance_type is None else x.instance_type.get_value(),
+            name = None if x.name is None else x.name.get_value(),
+            hostname = None if x.hostname is None else x.hostname.get_value(),
+            price = None if x.price is None else x.price.get_value(),
+            image_id = None if x.image_id is None else x.image_id.get_value(),
+            region_id = None if x.region_id is None else x.region_id.get_value(),
+            zone_id = None if x.zone_id is None else x.zone_id.get_value(),
+            internet_pay_type = None if x.internet_pay_type is None else x.internet_pay_type.get_value(),
+            pay_type = None if x.pay_type is None else x.pay_type.get_value(),
+            create_time = None if x.create_time is None else x.create_time.get_value(),
+            os_name = None if x.os_name is None else x.os_name.get_value(),
+            public_ip = None if x.public_ip is None else [m.get_value() for m in x.public_ip],
+            private_ip = None if x.private_ip is None else x.private_ip.get_value(),
+            bandwidth_in = None if x.bandwidth_in is None else x.bandwidth_in.get_value(),
+            bandwidth_out = None if x.bandwidth_out is None else x.bandwidth_out.get_value(),
+            expired_time = None if x.expired_time is None else x.expired_time.get_value(),
+            auto_release_time = None if x.auto_release_time is None else x.auto_release_time.get_value(),
+            key_name = None if x.key_name is None else x.key_name.get_value(),
+            _life_time = None if x._life_time is None else x._life_time.get_value()
+        )
+
+class InstanceUserSettingConverter(Converter):
+    def to_entity(self, do: InstanceUserSettingDO):
+        return InstanceUserSetting(
+            name = Name(do.name),
+            password = Password(do.password),
+            image_id = ImageID(do.image_id),
+            region_id = RegionID(do.region_id),
+            exclude_instance_types = [InstanceType(m) for m in do.exclude_instance_types],
+            user_data = Data(do.user_data),
+            internet_pay_type = Type(do.internet_pay_type),
+            amount = Number(do.amount),
+            bandwidth_in = BandWidth(do.bandwidth_in),
+            bandwidth_out = BandWidth(do.bandwidth_out),
+            disk_size = Size(do.disk_size),
+            key_name = Name(do.key_name),
+            inner_connection = Bool(do.inner_connection)
+        )
+    def to_do(self, x: InstanceUserSetting):
+        return InstanceUserSettingDO(
+            name = None if x.name is None else x.name.get_value(),
+            password = None if x.password is None else x.password.get_value(),
+            image_id = None if x.image_id is None else x.image_id.get_value(),
+            region_id = None if x.region_id is None else x.region_id.get_value(),
+            exclude_instance_types = None if x.exclude_instance_types is None else [m.get_value() for m in x.exclude_instance_types],
+            user_data = None if x.user_data is None else x.user_data.get_value(),
+            internet_pay_type = None if x.internet_pay_type is None else x.internet_pay_type.get_value(),
+            amount = None if x.amount is None else x.amount.get_value(),
+            bandwidth_in = None if x.bandwidth_in is None else x.bandwidth_in.get_value(),
+            bandwidth_out = None if x.bandwidth_out is None else x.bandwidth_out.get_value(),
+            disk_size = None if x.disk_size is None else x.disk_size.get_value(),
+            key_name = None if x.key_name is None else x.key_name.get_value(),
+            inner_connection = None if x.inner_connection is None else x.inner_connection.get_value()
+        )
+
+class CommandSettingConverter(Converter):
+    def to_entity(self, do: CommandSettingDO):
+        return CommandSetting(
+            command = Command(do.command),
+            forks = Number(do.forks),
+            timeout = Number(do.timeout),
+            password = Password(do.password),
+            username = Username(do.username),
+            port = Port(do.port),
+            inner_connection = Bool(do.inner_connection)
+        )
+    def to_do(self, x: CommandSetting):
+        return CommandSettingDO(
+            command = None if x.command is None else x.command.get_value(),
+            forks = None if x.forks is None else x.forks.get_value(),
+            timeout = None if x.timeout is None else x.timeout.get_value(),
+            password = None if x.password is None else x.password.get_value(),
+            username = None if x.username is None else x.username.get_value(),
+            port = None if x.port is None else x.port.get_value(),
+            inner_connection = None if x.inner_connection is None else x.inner_connection.get_value()
+        )
+
+class OSSOperationInfoConverter(Converter):
+    def to_entity(self, do: OSSOperationInfoDO):
+        return OSSOperationInfo(
+            name = Name(do.name),
+            endpoint = Endpoint(do.endpoint),
+            bucket_name = Name(do.bucket_name),
+            local_path = Path(do.local_path),
+            target_path = Path(do.target_path),
+            with_tar = Bool(do.with_tar)
+        )
+    def to_do(self, x: OSSOperationInfo):
+        return OSSOperationInfoDO(
+            name = None if x.name is None else x.name.get_value(),
+            endpoint = None if x.endpoint is None else x.endpoint.get_value(),
+            bucket_name = None if x.bucket_name is None else x.bucket_name.get_value(),
+            local_path = None if x.local_path is None else x.local_path.get_value(),
+            target_path = None if x.target_path is None else x.target_path.get_value(),
+            with_tar = None if x.with_tar is None else x.with_tar.get_value()
+        )
+
+class InstanceTypeWithStatusConverter(Converter):
+    def to_entity(self, do: InstanceTypeWithStatusDO):
+        return InstanceTypeWithStatus(
+            region_id = RegionID(do.region_id),
+            zone_id = ZoneID(do.zone_id),
+            instance_type_id = InstanceType(do.instance_type_id),
+            cpu_number = Number(do.cpu_number),
+            memory_size = Size(do.memory_size),
+            gpu_type = GPUType(do.gpu_type),
+            gpu_number = Number(do.gpu_number),
+            status = InstanceTypeStatus(do.status),
+            status_category = InstanceTypeStatusCategory(do.status_category),
+            _life_time = Number(do._life_time)
+        )
+    def to_do(self, x: InstanceTypeWithStatus):
+        return InstanceTypeWithStatusDO(
+            region_id = None if x.region_id is None else x.region_id.get_value(),
+            zone_id = None if x.zone_id is None else x.zone_id.get_value(),
+            instance_type_id = None if x.instance_type_id is None else x.instance_type_id.get_value(),
+            cpu_number = None if x.cpu_number is None else x.cpu_number.get_value(),
+            memory_size = None if x.memory_size is None else x.memory_size.get_value(),
+            gpu_type = None if x.gpu_type is None else x.gpu_type.get_value(),
+            gpu_number = None if x.gpu_number is None else x.gpu_number.get_value(),
+            status = None if x.status is None else x.status.get_value(),
+            status_category = None if x.status_category is None else x.status_category.get_value(),
+            _life_time = None if x._life_time is None else x._life_time.get_value()
+        )
+
+class InstanceTypeUserSettingConverter(Converter):
+    def to_entity(self, do: InstanceTypeUserSettingDO):
+        return InstanceTypeUserSetting(
+            region_id = RegionID(do.region_id),
+            zone_id = ZoneID(do.zone_id),
+            instance_type_id = InstanceType(do.instance_type_id)
+        )
+    def to_do(self, x: InstanceTypeUserSetting):
+        return InstanceTypeUserSettingDO(
+            region_id = None if x.region_id is None else x.region_id.get_value(),
+            zone_id = None if x.zone_id is None else x.zone_id.get_value(),
+            instance_type_id = None if x.instance_type_id is None else x.instance_type_id.get_value()
+        )
+
+class DNSRecordConverter(Converter):
+    def to_entity(self, do: DNSRecordDO):
+        return DNSRecord(
+            domain_name = DomainName(do.domain_name),
+            subdomain = Subdomain(do.subdomain),
+            value = Value(do.value),
+            id = RecordID(do.id),
+            weight = Weight(do.weight),
+            dns_type = DNSType(do.dns_type),
+            ttl = Number(do.ttl),
+            priority = Number(do.priority),
+            line = DNSLine(do.line)
+        )
+    def to_do(self, x: DNSRecord):
+        return DNSRecordDO(
+            domain_name = None if x.domain_name is None else x.domain_name.get_value(),
+            subdomain = None if x.subdomain is None else x.subdomain.get_value(),
+            value = None if x.value is None else x.value.get_value(),
+            id = None if x.id is None else x.id.get_value(),
+            weight = None if x.weight is None else x.weight.get_value(),
+            dns_type = None if x.dns_type is None else x.dns_type.get_value(),
+            ttl = None if x.ttl is None else x.ttl.get_value(),
+            priority = None if x.priority is None else x.priority.get_value(),
+            line = None if x.line is None else x.line.get_value()
+        )
+
+class ServiceConverter(Converter):
+    def to_entity(self, do: ServiceDO):
+        return Service(
+            name = Name(do.name),
+            service_type = ServiceType(do.service_type),
+            cluster_ip = IP(do.cluster_ip),
+            external_ip = IP(do.external_ip),
+            port_info = Info(do.port_info),
+            age = DateTime(do.age),
+            _life_time = Number(do._life_time)
+        )
+    def to_do(self, x: Service):
+        return ServiceDO(
+            name = None if x.name is None else x.name.get_value(),
+            service_type = None if x.service_type is None else x.service_type.get_value(),
+            cluster_ip = None if x.cluster_ip is None else x.cluster_ip.get_value(),
+            external_ip = None if x.external_ip is None else x.external_ip.get_value(),
+            port_info = None if x.port_info is None else x.port_info.get_value(),
+            age = None if x.age is None else x.age.get_value(),
+            _life_time = None if x._life_time is None else x._life_time.get_value()
         )
\ No newline at end of file
