@@ -143,59 +143,59 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         config_map_user_settings = [config_map_user_setting_converter.to_do(x) for x in config_map_user_settings]
         result = self.ao.create_config_maps(cluster_name, config_map_user_settings)
         if result.succeed:
-            return None
+            return True
         else:
             self.log_func(result.error_traceback)
-            return None
+            return False
 
     def create_namespace(self, cluster_name: Name, namespace_name: Name)->None:
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
         result = self.ao.create_namespace(cluster_name, namespace_name)
         if result.succeed:
-            return None
+            return True
         else:
             self.log_func(result.error_traceback)
-            return None
+            return False
 
     def create_resource_from_oss(self, cluster_name: Name, target_paths: List[Path])->None:
         cluster_name = cluster_name.get_value()
         target_paths = [x.get_value() for x in target_paths]
         result = self.ao.create_resource_from_oss(cluster_name, target_paths)
         if result.succeed:
-            return None
+            return True
         else:
             self.log_func(result.error_traceback)
-            return None
+            return False
 
-    def create_secrets(self, cluster_name: Name, secret_user_settings: List[SecretUserSetting])->None:
+    def create_secrets(self, cluster_name: Name, secret_user_settings: List[SecretUserSetting])->bool:
         cluster_name = cluster_name.get_value()
         secret_user_settings = [secret_user_setting_converter.to_do(x) for x in secret_user_settings]
         result = self.ao.create_secrets(cluster_name, secret_user_settings)
         if result.succeed:
-            return None
+            return True
         else:
             self.log_func(result.error_traceback)
-            return None
+            return False
 
     def delete_nodes(self, node_infos: List[NodeInfo])->None:
         node_infos = [node_info_converter.to_do(x) for x in node_infos]
         result = self.ao.delete_nodes(node_infos)
         if result.succeed:
-            return None
+            return True
         else:
             self.log_func(result.error_traceback)
-            return None
+            return False
 
     def delete_resource_from_oss(self, cluster_name: Name, target_paths: List[Path])->None:
         cluster_name = cluster_name.get_value()
         target_paths = [x.get_value() for x in target_paths]
         result = self.ao.delete_resource_from_oss(cluster_name, target_paths)
         if result.succeed:
-            return None
+            return True
         else:
             self.log_func(result.error_traceback)
-            return None
+            return False
 
     def _get_config_maps(self, cluster_name: Name, namespace_name: Name)->Optional[List[ConfigMap]]:
         cluster_name = cluster_name.get_value()
@@ -335,10 +335,10 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         pod_oss_operation_info = pod_oss_operation_info_converter.to_do(pod_oss_operation_info)
         result = self.ao.upload_to_oss_from_pod(pod_oss_operation_info)
         if result.succeed:
-            return None
+            return True
         else:
             self.log_func(result.error_traceback)
-            return None
+            return False
 
     def _get_ingresses(self, cluster_name: Name, namespace_name: Name)->Optional[List[Ingress]]:
         cluster_name = cluster_name.get_value()
